MoneroNodeRpcInterfaceWrapper

Struct MoneroNodeRpcInterfaceWrapper 

pub struct MoneroNodeRpcInterfaceWrapper<S: SSHOrCommandLike> {
    pub wallet_rpc: MoneroRpcWrapper,
    pub daemon_rpc: MoneroRpcWrapper,
    pub state: MoneroWalletMultisigRpcState,
    pub cmd: S,
    pub wallet_dir: String,
    pub wallet_expect_contents: String,
    pub allow_deletes: bool,
    pub create_states: Vec<MoneroWalletMultisigRpcState>,
    pub history: Vec<StateHistoryItem>,
}
This is the main interface the internal node process uses to interact with the Monero network. It should primarily and only be used for multi-sig operations It is not thread-safe, interactions with the docker process running the wallet daemon should be done in a single-threaded manner. More importantly, each interaction updates this interface’s internal state (representing the wallets external state)

Fields

wallet_rpc: MoneroRpcWrapperdaemon_rpc: MoneroRpcWrapperstate: MoneroWalletMultisigRpcStatecmd: Swallet_dir: Stringwallet_expect_contents: Stringallow_deletes: boolcreate_states: Vec<MoneroWalletMultisigRpcState>history: Vec<StateHistoryItem>

Implementations

Source

impl<S: SSHOrCommandLike> MoneroNodeRpcInterfaceWrapper<S>

pub fn reset(&mut self)

pub fn any_multisig_addr_creation(&self) -> Option<String>

pub fn any_multisig_addr_history(&self) -> Option<String>

pub fn from_config_local( nc: &NodeConfig, wallet_dir: impl Into<String>, expect_path: impl Into<String>, allow_deletes: Option<bool>, ) -> Option<RgResult<MoneroNodeRpcInterfaceWrapper<LocalSSHLike>>>

pub fn from_config( nc: &NodeConfig, cmd: S, wallet_dir: impl Into<String>, expect_contents: impl Into<String>, allow_deletes: Option<bool>, ) -> Option<RgResult<MoneroNodeRpcInterfaceWrapper<S>>>

pub async fn set_as_multisig_self( &mut self, x: &String, restore_height: Option<i64>, restore_from_daemon_cur: bool, ) -> RgResult<()>

pub async fn restore_from_history( &mut self, h: Vec<StateHistoryItem>, wallet_filename: &String, ) -> RgResult<()>

pub fn get_secret(&self) -> RgResult<PartySecretInstanceData>

pub async fn start_multisig_creation( &mut self, wallet_filename: &String, skip_init: bool, ) -> RgResult<String>

pub async fn refresh_sync_check_daemon_against_wallet(&self) -> RgResult<i64>

pub async fn get_balance_all_info(&self) -> RgResult<BalanceData>

pub async fn prepare_wallet_fnm_and_set_multisig( &mut self, wallet_filename_relative: &String, restore_height: Option<i64>, restore_from_daemon_cur: bool, ) -> Result<(), ErrorInfo>

pub async fn multisig_create_loop<B>( &mut self, all_pks: &Vec<PublicKey>, threshold: i64, peer_broadcast: &B, ) -> RgResult<PartySecretInstanceData>
where B: PeerBroadcast,

pub fn get_wallet_filename_id( all_pks: &Vec<PublicKey>, threshold: i64, ) -> String

pub async fn multisig_create_next( &mut self, peer_strings: Option<Vec<String>>, threshold: Option<i64>, wallet_filename: &String, skip_initial: bool, max_num_rounds: i64, ) -> RgResult<MoneroWalletMultisigRpcState>

pub async fn multisig_send_prepare_and_sign( &mut self, amounts: Vec<(Address, CurrencyAmount)>, ) -> RgResult<(TransferResult, SignedMultisigTxset)>

pub async fn make_multisig( &mut self, peer_strings: Vec<String>, threshold: i64, ) -> RgResult<MakeMultisigResult>

pub async fn exchange_multisig_keys( &mut self, peer_strings: Vec<String>, ) -> RgResult<ExchangeMultisigKeysResult>

pub async fn export_multisig_info(&mut self) -> RgResult<String>

pub async fn import_multisig_info(&mut self, info: Vec<String>) -> RgResult<u64>

pub async fn submit_multisig_transaction( &mut self, tx_data_hex: String, ) -> RgResult<Vec<String>>

pub async fn describe_multisig_transaction( &mut self, unsigned_txset: String, ) -> RgResult<DescribeTransferResult>